@@ -28,7 +28,7 @@ def make_pipeline(name, folders, search=af.DynestyStatic()):
                 redshift=0.5, mass=phase1.result.model.galaxies.lens.mass
             ),
             source_0=al.GalaxyModel(
-                redshift=1.0, light=phase1.result.model.galaxies.source_0.light
+                redshift=1.0, light=phase1.result.model.galaxies.source_0.setup_light
             ),
             source_1=al.GalaxyModel(redshift=1.0, light=al.lp.EllipticalSersic),
         ),
